@@ -37,10 +37,12 @@ POSSIBILITY OF SUCH DAMAGE.
 
 #include <boost/bind.hpp>
 #include <boost/shared_ptr.hpp>
+#include <boost/make_shared.hpp>
 
 #include "libtorrent/aux_/disable_warnings_pop.hpp"
 
 #include "libtorrent/proxy_base.hpp"
+#include "libtorrent/broadcast_socket.hpp" // for is_ip_address
 #include "libtorrent/assert.hpp"
 #if defined TORRENT_ASIO_DEBUGGING
 #include "libtorrent/debug.hpp"
@@ -74,7 +76,12 @@ namespace socks_error {
 } // namespace socks_error
 
 // returns the error_category for SOCKS5 errors
-TORRENT_EXPORT boost::system::error_category& get_socks_category();
+TORRENT_EXPORT boost::system::error_category& socks_category();
+
+#ifndef TORRENT_NO_DEPRECATE
+TORRENT_DEPRECATED TORRENT_EXPORT
+boost::system::error_category& get_socks_category();
+#endif
 
 class socks5_stream : public proxy_base
 {
@@ -83,7 +90,6 @@ public:
 	// commands
 	enum {
 		socks5_connect = 1,
-		socks5_bind = 2,
 		socks5_udp_associate = 3
 	};
 
@@ -91,14 +97,13 @@ public:
 		: proxy_base(io_service)
 		, m_version(5)
 		, m_command(socks5_connect)
-		, m_listen(0)
 	{}
 
 	void set_version(int v) { m_version = v; }
 
 	void set_command(int c)
 	{
-		TORRENT_ASSERT(c >= socks5_connect && c <=socks5_udp_associate);
+		TORRENT_ASSERT(c == socks5_connect || c == socks5_udp_associate);
 		m_command = c;
 	}
 
@@ -111,17 +116,10 @@ public:
 
 	void set_dst_name(std::string const& host)
 	{
-		// TODO: 3 enable this assert and fix remaining causes of it triggering
-/*
-#if TORRENT_USE_ASSERTS
-		error_code ec;
-		address::from_string(host, ec);
 		// if this assert trips, set_dst_name() is called wth an IP address rather
 		// than a hostname. Instead, resolve the IP into an address and pass it to
 		// async_connect instead
-		TORRENT_ASSERT(ec);
-#endif
-*/
+		TORRENT_ASSERT(!is_ip_address(host.c_str()));
 		m_dst_name = host;
 		if (m_dst_name.size() > 255)
 			m_dst_name.resize(255);
@@ -147,8 +145,7 @@ public:
 	{
 		// make sure we don't try to connect to INADDR_ANY. binding is fine,
 		// and using a hostname is fine on SOCKS version 5.
-		TORRENT_ASSERT(m_command == socks5_bind
-			|| endpoint.address() != address()
+		TORRENT_ASSERT(endpoint.address() != address()
 			|| (!m_dst_name.empty() && m_version == 5));
 
 		m_remote_endpoint = endpoint;
@@ -194,15 +191,11 @@ private:
 	std::string m_user;
 	std::string m_password;
 	std::string m_dst_name;
+
 	int m_version;
 
-	// the socks command to send for this connection (connect, bind,
-	// udp associate)
+	// the socks command to send for this connection (connect or udp associate)
 	int m_command;
-
-	// set to one when we're waiting for the
-	// second message to accept an incoming connection
-	int m_listen;
 };
 
 }
@@ -212,8 +205,6 @@ namespace boost { namespace system {
 	template<> struct is_error_code_enum<libtorrent::socks_error::socks_error_code>
 	{ static const bool value = true; };
 
-	template<> struct is_error_condition_enum<libtorrent::socks_error::socks_error_code>
-	{ static const bool value = true; };
 } }
 
 #endif
